@@ -57,17 +57,18 @@ import java.util.ArrayList;
 import java.util.List;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpException;
+import org.apache.commons.httpclient.cookie.CookiePolicy;
 import org.apache.commons.httpclient.methods.GetMethod;
 import org.apache.commons.httpclient.methods.PostMethod;
 import org.apache.commons.httpclient.methods.RequestEntity;
 import org.apache.commons.httpclient.methods.StringRequestEntity;
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.log.LogFactory;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.msn.osgi.MSNOAuthActivator;
@@ -97,7 +98,7 @@ public class MSNServiceImpl implements MSNService {
             final com.openexchange.oauth.OAuthService oAuthService = activator.getOauthService();
             account = oAuthService.getAccount(accountId, session, user, contextId);
             // the account contains the refresh-token in this case
-            final String wrap_access_token = useRefreshTokenToGetAccessToken(account);
+            final String wrap_access_token = useRefreshTokenToGetAccessToken(account, session);
             final JSONObject response = useAccessTokenToAccessData(wrap_access_token);
             contacts = parseIntoContacts(wrap_access_token, response);
 
@@ -121,6 +122,8 @@ public class MSNServiceImpl implements MSNService {
 
             final HttpClient client = new HttpClient();
             client.getParams().setParameter("http.protocol.content-charset", "UTF-8");
+            client.getParams().setParameter("http.protocol.single-cookie-header", Boolean.TRUE);
+            client.getParams().setCookiePolicy(CookiePolicy.BROWSER_COMPATIBILITY);
             final int responseCode = client.executeMethod(getMethod);
             String response = getMethod.getResponseBodyAsString();
             wholeResponse = new JSONObject(response);
@@ -235,11 +238,12 @@ public class MSNServiceImpl implements MSNService {
     }
 
     /**
+     * @param session
      * @param secret
      * @param token
      * @throws OXException
      */
-    private String useRefreshTokenToGetAccessToken(OAuthAccount account) throws OXException {
+    private String useRefreshTokenToGetAccessToken(OAuthAccount account, Session session) throws OXException {
     	String callback = null;
     	try {
     		JSONObject metadata = new JSONObject(account.getSecret());
@@ -251,7 +255,9 @@ public class MSNServiceImpl implements MSNService {
 
     	try {
     		final HttpClient client = new HttpClient();
-    		final PostMethod postMethod = new PostMethod("https://login.live.com/oauth20_token.srf?client_id=" + account.getMetaData().getAPIKey() + "&redirect_uri=" + URLEncoder.encode(callback, "UTF-8") + "&client_secret=" + URLEncoder.encode(account.getMetaData().getAPISecret(), "UTF-8")+"&refresh_token=" + account.getToken() + "&grant_type=refresh_token");
+    		client.getParams().setParameter("http.protocol.single-cookie-header", Boolean.TRUE);
+            client.getParams().setCookiePolicy(CookiePolicy.BROWSER_COMPATIBILITY);
+    		final PostMethod postMethod = new PostMethod("https://login.live.com/oauth20_token.srf?client_id=" + account.getMetaData().getAPIKey(session) + "&redirect_uri=" + URLEncoder.encode(callback, "UTF-8") + "&client_secret=" + URLEncoder.encode(account.getMetaData().getAPISecret(session), "UTF-8")+"&refresh_token=" + account.getToken() + "&grant_type=refresh_token");
 
     		RequestEntity requestEntity;
             requestEntity = new StringRequestEntity(postMethod.getQueryString(), "application/x-www-form-urlencoded", "UTF-8");
