@@ -52,7 +52,11 @@ package com.openexchange.oauth;
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
 import java.util.Map;
+import org.apache.commons.logging.Log;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.oauth.services.Services;
+import com.openexchange.session.Session;
 
 /**
  * {@link AbstractOAuthServiceMetaData} - The default {@link OAuthServiceMetaData} implementation.
@@ -61,11 +65,16 @@ import com.openexchange.exception.OXException;
  */
 public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaData {
 
+    private static final Log LOG = com.openexchange.log.Log.loggerFor(AbstractOAuthServiceMetaData.class);
+
     protected String id;
     protected String displayName;
     protected String apiKey;
     protected String apiSecret;
 
+    protected String apiKeyName;
+    protected String apiSecretName;
+
     /**
      * Initializes a new {@link AbstractOAuthServiceMetaData}.
      */
@@ -85,14 +94,71 @@ public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaDa
 
     @Override
     public String getAPIKey() {
+        if (apiKey == null && apiKeyName != null) {
+            try {
+                return Services.getService(ConfigViewFactory.class).getView().get(apiKeyName, String.class);
+            } catch (final OXException e) {
+                LOG.warn("Couldn't look-up API key name.", e);
+            }
+        }
         return apiKey;
     }
 
+
+    /**
+     * Used to look up the apiKey in the config cascade
+     *
+     * @param apiKeyName The apiKeyName to set
+     */
+    public void setAPIKeyName(String apiKeyName) {
+        this.apiKeyName = apiKeyName;
+    }
+
+
+    /**
+     * Used to look up the apiSecret in the config cascade
+     *
+     * @param apiSecretName The apiSecretName to set
+     */
+    public void setAPISecretName(String apiSecretName) {
+        this.apiSecretName = apiSecretName;
+    }
+
+    @Override
+    public String getAPIKey(Session session) throws OXException {
+        if (session == null || apiKeyName == null) {
+            return getAPIKey();
+        }
+        int context = 0, user = 0;
+        context = session.getContextId();
+        user = session.getUserId();
+        return Services.getService(ConfigViewFactory.class).getView(user, context).get(apiKeyName, String.class);
+    }
+
     @Override
     public String getAPISecret() {
+        if (apiSecret == null && apiSecretName != null) {
+            try {
+                return Services.getService(ConfigViewFactory.class).getView().get(apiSecretName, String.class);
+            } catch (final OXException e) {
+                LOG.warn("Couldn't look-up API secret name.", e);
+            }
+        }
         return apiSecret;
     }
 
+
+    @Override
+    public String getAPISecret(Session session) throws OXException {
+        if (session == null || apiSecretName == null) {
+            return getAPISecret();
+        }
+        int context = 0, user = 0;
+        context = session.getContextId();
+        user = session.getUserId();
+        return Services.getService(ConfigViewFactory.class).getView(user, context).get(apiSecretName, String.class);
+    }
+
     /**
      * Sets the identifier
      *
@@ -113,7 +179,7 @@ public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaDa
 
     /**
      * Sets the API Key
-     *
+     * @deprecated: Implement {@link #getAPIKey(Session)} instead
      * @param apiKey The API Key to set
      */
     public void setApiKey(final String apiKey) {
@@ -123,6 +189,7 @@ public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaDa
     /**
      * Sets the API Secret
      *
+     * @deprecated: Implement {@link #getAPISecret(Session)} instead.
      * @param apiSecret The API Secret to set
      */
     public void setApiSecret(final String apiSecret) {
@@ -140,7 +207,7 @@ public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaDa
     }
 
     @Override
-    public OAuthInteraction initOAuth(final String callbackUrl) throws OXException {
+    public OAuthInteraction initOAuth(final String callbackUrl, Session session) throws OXException {
         return null;
     }
 
@@ -165,7 +232,7 @@ public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaDa
     }
 
     @Override
-    public String modifyCallbackURL(final String callbackUrl) {
+    public String modifyCallbackURL(final String callbackUrl, Session session) {
         return callbackUrl;
     }
 
